==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaRecepta.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajRealizacjiRecept;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class RealizacjaRecepta extends GenericDPSObject {
    /**
     * REALIZACJA_RECEPTA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * REALIZACJA_RECEPTA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaDpsId;

    /**
     * REALIZACJA_RECEPTA.FAKTURA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long fakturaId;

    /**
     * REALIZACJA_RECEPTA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * REALIZACJA_RECEPTA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * REALIZACJA_RECEPTA.RODZAJ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajRealizacjiRecept rodzaj;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_RECEPTA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * REALIZACJA_RECEPTA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return REALIZACJA_RECEPTA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * REALIZACJA_RECEPTA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return REALIZACJA_RECEPTA.FAKTURA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getFakturaId() {
        return fakturaId;
    }

    /**
     * REALIZACJA_RECEPTA.FAKTURA_ID
     *
     * @param fakturaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setFakturaId(Long fakturaId) {
        this.fakturaId = fakturaId;
    }

    /**
     * @return REALIZACJA_RECEPTA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * REALIZACJA_RECEPTA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return REALIZACJA_RECEPTA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * REALIZACJA_RECEPTA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return REALIZACJA_RECEPTA.RODZAJ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajRealizacjiRecept getRodzaj() {
        return rodzaj;
    }

    /**
     * REALIZACJA_RECEPTA.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzaj(RodzajRealizacjiRecept rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaRecepta other = (RealizacjaRecepta) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getFakturaId() == null ? other.getFakturaId() == null : this.getFakturaId().equals(other.getFakturaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getFakturaId() == null) ? 0 : getFakturaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", fakturaId=").append(fakturaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", data=").append(data);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaRecepta.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajRealizacjiRecept;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class RealizacjaRecepta extends GenericDPSObject {
    /**
     * REALIZACJA_RECEPTA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * REALIZACJA_RECEPTA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaDpsId;

    /**
     * REALIZACJA_RECEPTA.FAKTURA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long fakturaId;

    /**
     * REALIZACJA_RECEPTA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * REALIZACJA_RECEPTA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * REALIZACJA_RECEPTA.RODZAJ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajRealizacjiRecept rodzaj;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_RECEPTA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * REALIZACJA_RECEPTA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return REALIZACJA_RECEPTA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * REALIZACJA_RECEPTA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return REALIZACJA_RECEPTA.FAKTURA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getFakturaId() {
        return fakturaId;
    }

    /**
     * REALIZACJA_RECEPTA.FAKTURA_ID
     *
     * @param fakturaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setFakturaId(Long fakturaId) {
        this.fakturaId = fakturaId;
    }

    /**
     * @return REALIZACJA_RECEPTA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * REALIZACJA_RECEPTA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return REALIZACJA_RECEPTA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * REALIZACJA_RECEPTA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return REALIZACJA_RECEPTA.RODZAJ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajRealizacjiRecept getRodzaj() {
        return rodzaj;
    }

    /**
     * REALIZACJA_RECEPTA.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzaj(RodzajRealizacjiRecept rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaRecepta other = (RealizacjaRecepta) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getFakturaId() == null ? other.getFakturaId() == null : this.getFakturaId().equals(other.getFakturaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getFakturaId() == null) ? 0 : getFakturaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", fakturaId=").append(fakturaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", data=").append(data);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append("]");
        return sb.toString();
    }
}
